//
//  YHMyDocumentsDetailViewController.swift
//  galaxy
//
//  Created by EDY on 2024/3/15.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import SafariServices

class YHMyDocumentsDetailViewController: YHBaseViewController {
    
    var stepView: YHStepView!
    var bottomView: UIView!
    var bottomButton: UIButton!
    var tableView: UITableView!
    var dataSource: [YHWorkItemListModel]?
    var viewModel: YHMyDocumentsDetailViewModel!
    var id: Int = 0
    
    override func viewDidLoad() {
        super.viewDidLoad()
        viewModel = YHMyDocumentsDetailViewModel()
        gk_navTitle = "文书操作"
        gk_navBackgroundColor = .white
        gk_navBarAlpha = 1
        setView()
        getData()
        // Do any additional setup after loading the view.
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        getData()
    }
    
    func getData() {
        viewModel.requestDocumentsDetail("\(id)", callBackBlock: {[weak self] success, error in
            guard let self = self else { return }
            if self.viewModel.mainModel?.prospectus.id != 0 {
                self.stepView.snp.remakeConstraints { make in
                    make.top.equalTo(k_Height_NavigationtBarAndStatuBar)
                    make.left.right.equalTo(self.view)
                    make.height.equalTo(0)
                }
                self.bottomView.isHidden = true
            }
            if self.viewModel.mainModel?.writing_document.doc_sign.supplement_id == 0 {
                self.stepView.currentIndex = 0
                self.bottomView.isHidden = true
            } else {
                self.stepView.currentIndex = 1
            }
            self.tableView.reloadData()
        })
    }
    
    func updateDataSource() {
       
        self.tableView.reloadData()
    }
    
    func setView() {
        view.backgroundColor = .contentBkgColor
        stepView = {
            let step = YHStepView()
            step.dataSource = ["文书稿件", "文书签章"]
            return step
        }()
        view.addSubview(stepView)
        stepView.snp.makeConstraints { make in
            make.top.equalTo(k_Height_NavigationtBarAndStatuBar)
            make.left.right.equalTo(view)
            make.height.equalTo(104)
        }
        
        tableView = {
            let tableView = UITableView(frame:.zero, style:.grouped)
            if #available(iOS 11.0, *) {
                tableView.contentInsetAdjustmentBehavior = .never
            }
            tableView.backgroundColor = .clear
            tableView.separatorStyle = .none
            tableView.delegate = self
            tableView.dataSource = self
            tableView.register(cellWithClass: YHDocumentMessageTableViewCell.self)
            tableView.register(cellWithClass: YHDocumentPromptTableViewCell.self)
            tableView.register(cellWithClass: YHDocumentToActionTableViewCell.self)
            tableView.register(cellWithClass: YHDocumentUploadTableViewCell.self)
            return tableView
        }()
        view.addSubview(tableView)
        tableView.snp.makeConstraints { make in
            make.top.equalTo(k_Height_NavigationtBarAndStatuBar + YHStepView.height)
            make.bottom.equalTo(-k_Height_safeAreaInsetsBottom() - 64)
            make.left.right.bottom.equalTo(view)
        }
        
        bottomView = {
            let bottom = UIView()
            bottom.backgroundColor = .white
            return bottom
        }()
        view.addSubview(bottomView)
        bottomView.snp.makeConstraints { make in
            make.left.right.bottom.equalToSuperview()
            make.height.equalTo(k_Height_safeAreaInsetsBottom() + 64)
        }
        
        bottomButton = {
            let button = UIButton(type: .custom)
//            button.backgroundColor =  UIColor(hex:0x2274ee)
            button.titleLabel?.font = UIFont.PFSC_M(ofSize: 16)
            button.contentHorizontalAlignment = .center
            button.setTitle("确定已签章，提交", for: .normal)
            button.setTitleColor( UIColor(hex:0xffffff), for: .normal)
            button.layer.cornerRadius = kCornerRadius6
            button.clipsToBounds = true
            button.addTarget(self, action: #selector(submit), for: .touchUpInside)
            return button
        }()
        bottomView.addSubview(bottomButton)
        bottomButton.snp.makeConstraints { make in
            make.right.equalTo(-16)
            make.top.equalTo(8)
            make.height.equalTo(48)
            make.left.equalTo(16)
        }
        
        bottomButton.layoutIfNeeded()
        bottomButton.addYinHeGradualLayer()
    }
    
    @objc func submit() {
        let url = URL(string: "https://baidu.com/")!
        let safariViewController = SFSafariViewController(url: url)
        safariViewController.dismissButtonStyle = .close
        safariViewController.delegate = self
        self.navigationController?.pushViewController(safariViewController)
    }
    
    func showSureAlert() {
        YHCommonAlertView.show("", "请确认是否已完成编辑并提交", "取消", "确认") {[weak self] in
            guard let self = self else { return }
            self.viewModel.requestDocumentSubmit("\(self.id)") {[weak self] success, error in
                guard let self = self else { return }
                if success {
                    self.navigationController?.popViewController()
                }
            }
        }
    }
}

extension YHMyDocumentsDetailViewController: UITableViewDelegate, UITableViewDataSource {
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        if stepView.currentIndex == 0 {
            return 1
        }
        return 3
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        if stepView.currentIndex == 0 {
            let cell = tableView.dequeueReusableCell(withClass: YHDocumentMessageTableViewCell.self)
            cell.dataSource = self.viewModel.mainModel
            cell.backgroundColor = .clear
            cell.contentView.backgroundColor = .clear
            cell.block = {[weak self] type in
                guard let self = self else { return }
                if type == .edit {
                    if self.viewModel.mainModel?.prospectus.id != 0 {
                        // 跳转赴港计划书编辑页面
                    } else {
                        self.viewModel.requestDocumentsTemporaryUrl("\(id)", callBackBlock: {[weak self] success, error in
                            guard let self = self else { return }
                            if success {
                                self.viewModel.requestDocumentRecord("\(id)", 2) { success, error in
                                }
                                guard let url = URL(string: self.viewModel?.urlModel?.url) else { return }
                                let tmpVC = SFSafariViewController(url: url)
                                tmpVC.dismissButtonStyle = .close
                                tmpVC.delegate = self
                                self.navigationController?.pushViewController(tmpVC)
                            } else {
                                YHHUD.flash(message: error?.errorMsg ?? "")
                            }
                        })
                    }
                }
                
                if type == .submit {
                    self.showSureAlert()
                }
                
                if type == .look {
                    if self.viewModel.mainModel?.prospectus.id != 0 {
                        // 跳转赴港计划书查看页面
                    } else {
                        self.viewModel.requestDocumentRecord("\(id)", 1) { success, error in
                        }
                        guard let url = URL(string: self.viewModel.mainModel?.writing_document.tencent_file_url ?? "") else { return }
                        let tmpVC = SFSafariViewController(url: url)
                        tmpVC.dismissButtonStyle = .close
                        tmpVC.delegate = self
                        self.navigationController?.pushViewController(tmpVC)
                    }
                }
            }
            return cell
        } else {
            if indexPath.row == 0 {
                let cell = tableView.dequeueReusableCell(withClass: YHDocumentPromptTableViewCell.self)
                cell.backgroundColor = .clear
                cell.contentView.backgroundColor = .clear
                return cell
            } else if indexPath.row == 1 {
                let cell = tableView.dequeueReusableCell(withClass: YHDocumentToActionTableViewCell.self)
                cell.dataSource = self.viewModel.mainModel?.writing_document.doc_sign
                cell.backgroundColor = .clear
                cell.contentView.backgroundColor = .clear
                cell.block = { [weak self] type in
                    guard let self = self else { return }
                    if type == .sign {
                        self.viewModel.requestSignaturePageURL("\(id)", callBackBlock: {[weak self] success, error in
                            guard let self = self else { return }
                            if error?.errorCode == 1008611 {
                                YHCommonAlertView.show("实名认证", "为保证签署有效，请先实名认证", "取消", "去认证") {
                                    self.viewModel.requestSignaturePersonalURL(callBackBlock: {[weak self] success, error in
                                        guard let self = self else { return }
                                        let url = URL(string: self.viewModel.personalUrl)!
                                        let safariViewController = SFSafariViewController(url: url)
                                        safariViewController.dismissButtonStyle = .close
                                        safariViewController.delegate = self
                                        self.navigationController?.pushViewController(safariViewController)
                                    })
                                }
                            } else {
                                if success ?? false {
                                    let url = URL(string: self.viewModel.pageUrl)!
                                    let safariViewController = SFSafariViewController(url: url)
                                    safariViewController.dismissButtonStyle = .close
                                    safariViewController.delegate = self
                                    self.navigationController?.pushViewController(safariViewController)
                                } else {
                                    YHHUD.flash(message: error?.errorMsg ?? "")
                                }
                            }
                        })
                    }
                    
                    if type == .look {
                        self.viewModel.requestSignatureLook("\(id)") {[weak self] success, error in
                            guard let self = self else { return }
                            if success {
                                let url = URL(string: self.viewModel.pageUrl)!
                                let safariViewController = SFSafariViewController(url: url)
                                safariViewController.dismissButtonStyle = .close
                                safariViewController.delegate = self
                                self.navigationController?.pushViewController(safariViewController)
                            } else {
                                YHHUD.flash(message: error?.errorMsg ?? "")
                            }
                        }
                    }
                    
                    if type == .downLoad {
                        self.viewModel.requestSignatureDownload("\(id)") { [weak self] success, error in
                            guard let self = self else { return }
                            //获取到下载链接发送到邮箱
                        }
                    }
                }
                return cell
            } else {
                let cell = tableView.dequeueReusableCell(withClass: YHDocumentUploadTableViewCell.self)
                cell.dataSource = self.viewModel.mainModel?.writing_document.doc_sign
                cell.backgroundColor = .clear
                cell.contentView.backgroundColor = .clear
                cell.block = { [weak self] type, index in
                    guard let self = self else { return }
                    if type == .upload {
                        let sheetView = YHCertificateUploadSheetView.sheetView()
//                        sheetView.maxSelectCount = 99-items.count
//                        sheetView.templateInfo = supplementInfo.templateInfo
//                        sheetView.uploadFilesBlock = {
//                            [weak self] fileUrl in
//                            guard let self = self else { return }
//                            print(fileUrl)
//                            uploadFile(fileUrl)
//                        }
//                        sheetView.uploadImageBlock = {
//                            [weak self] imgArr in
//                            guard let self = self else { return }
//                            let group = DispatchGroup()
//                            var successArr:[YHSelectImageItem] = []
//                            var failArr:[YHSelectImageItem] = []
//
//                            YHHUD.show(.progress(message: "上传中..."))
//                            for item in imgArr {
//                                if let image = item.data {
//                                    group.enter()
//                                    uploadImage(image, imageName:item.name) {
//                                        success in
//                                        if success {
//                                            successArr.append(item)
//                                        } else {
//                                            failArr.append(item)
//                                        }
//                                        group.leave()
//                                    }
//                                }
//                            }
//                            
//                            // 等待所有任务完成
//                            group.notify(queue: .main) {
//                                // 所有任务完成，回到主线程继续执行
//                                print("所有任务完成")
//                                if imgArr.count == successArr.count {
//                                    YHHUD.flash(message: "上传成功")
//                                    
//                                } else {
//                                    YHHUD.flash(message: "\(successArr.count)张照片上传成功\n\(failArr.count)张照片上传失败")
//                                }
//                                YHHUD.hide()
//                            }
//                        }
                        sheetView.show()
                    }
                    
                    if type == .reUpload {
                        
                    }
                    
                    if type == .delete {
                        
                    }
                }
                return cell
            }
        }
        
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        if stepView.currentIndex == 0 {
            return 190
        } else {
            if indexPath.row == 0 {
                return 104
            } else if indexPath.row == 1 {
                return 180
            } else {
                return 221
            }
        }
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
    }
    
    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        let view = UIView(frame: CGRect(x: 0, y: 0, width: KScreenWidth, height: 7))
        return view
    }
    
    func tableView(_ tableView: UITableView, heightForHeaderInSection section: Int) -> CGFloat {
        return 7
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        return UIView()
    }
    
    func tableView(_ tableView: UITableView, heightForFooterInSection section: Int) -> CGFloat {
        return 0.01
    }
}

extension YHMyDocumentsDetailViewController: SFSafariViewControllerDelegate {
    // MARK: 点击左上角的完成
    func safariViewControllerDidFinish(_ controller: SFSafariViewController) {
        controller.navigationController?.popViewController()
    }

    // MARK: 加载完成
    func safariViewController(_ controller: SFSafariViewController, didCompleteInitialLoad didLoadSuccessfully: Bool) {
        print(#function)
    }
    
    // MARK: 点击右下角调用Safari浏览器打开
    func safariViewControllerWillOpenInBrowser(_ controller: SFSafariViewController) {
        print(#function)
    }
}
